/*
  Turtlebot button interface
  by Bob Mottram
   
 The circuit:
 * pushbutton attached to pin 22-26 from +5V
 * 10K resistor attached to pin 22-26 from ground
 * LED attached from pin 13 to ground (or use the built-in LED on
   most Arduino boards)
 
 */

// this constant won't change:
const int  buttonPin[] = {22,23,24,25,26};    // the pin that the pushbutton is attached to
const int ledPin = 13;       // the pin that the LED is attached to

// Variables will change:
int buttonState = 0;         // current state of the button
int lastButtonState[] = {0,0,0,0,0};     // previous state of the button

void setup() {
  // initialize the button pin as a input:
  for (int i=0;i<5;i++) {
    pinMode(buttonPin[i], INPUT);
  }
  // initialize the LED as an output:
  pinMode(ledPin, OUTPUT);
  // initialize serial communication:
  Serial.begin(9600);
}


void loop() {
  for (int i=0;i<5;i++) {
    // read the pushbutton input pin:
    buttonState = digitalRead(buttonPin[i]);
  
    // compare the buttonState to its previous state
    if (buttonState != lastButtonState[i]) {
      // if the state has changed, increment the counter
      if (buttonState == HIGH) {
        // if the current state is HIGH then the button
        // wend from off to on:
        Serial.println(i, DEC);
        digitalWrite(ledPin, HIGH);
      }
      else {
        // if the current state is LOW then the button
        // wend from on to off:
        digitalWrite(ledPin, LOW);
      }
    }
    // save the current state as the last state,
    //for next time through the loop
    lastButtonState[i] = buttonState;  
  } 
}
